@@ -26,9 +26,9 @@ class package(PkgbuildRule):
 	def analyze(self, pkginfo, tar):
 		if 'source' in pkginfo:
 			for source in pkginfo["source"]:
-				if re.match('(http://|ftp://)\w+.dl.(sourceforge|sf).net', source) != None:
+				if re.match('(http://|ftp://)\w+.dl.(sourceforge|sf).net', source):
 					self.warnings.append(("specific-sourceforge-mirror", ()))
-				if re.match('(http://|ftp://)dl.(sourceforge|sf).net', source) != None:
+				if re.match('(http://|ftp://)dl.(sourceforge|sf).net', source):
 					self.warnings.append(("using-dl-sourceforge", ()))
 
 # vim: set ts=4 sw=4 noet:
